OC.L10N.register(
    "activity",
    {
    "Activities" : "Totes les activitats",
    "An error occurred while loading activities" : "S'ha produït un error mentre que es carregaven les activitats",
    "No activity yet" : "Cap activitat encara",
    "Load more activities" : "Carrega més activitats",
    "Copied!" : "Copiat!",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Prem ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Prem Ctrl-C per copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringit)",
    "in {path}" : "a {path}",
    "This stream will show events like additions, changes & shares" : "Aquest flux mostrarà esdeveniments afegits, modificats i compartits.",
    "There are no events for this filter" : "No hi ha esdeveniments per aquest filtre",
    "Today" : "Avui",
    "Yesterday" : "Ahir",
    "Personal activity feed for %s" : "Canal d'activitat personal per a %s",
    "Your feed URL is invalid" : "La URL del canal no és vàlida",
    "Your settings have been updated." : "La configuració s'ha actualitzat.",
    "Settings have been updated." : "Els ajustos s'han actualitzat.",
    "Mail" : "Correu electrònic",
    "Stream" : "Flux",
    "All activities" : "Totes les activitats",
    "By others" : "Per altres",
    "By you" : "Per tu",
    "\"remote user\"" : "\"usuari remot\"",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Hi va haver activitat a %s",
    "_and %n more _::_and %n more _" : ["i %n més","i %n més"],
    "Activity notification" : "Notificació d'activitat",
    ", " : ", ",
    "%s and %s" : "%s i %s",
    "Activity" : "Activitat",
    "Activity feed" : "Canal d'activitat",
    "Configure the default activity settings for new users." : "Configura els valors d'activitat per defecte per als nous usuaris.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Trieu per quines activitats voleu obtenir una notificació per correu electrònic i que ha d'aparèixer en el flux de treball de les apps.",
    "List your own actions in the stream" : "Llista les seves pròpies accions al flux",
    "Notify about your own actions via email" : "Notifica sobre les seves pròpies accions via email",
    "You need to set up your email address before you can receive notification emails." : "Heu d'establir l'adreça de correu electrònic abans que pugueu rebre correus de notificació",
    "Send emails:" : "Envia correus electrònics:",
    "Hourly" : "Horàriament",
    "Daily" : "Diari",
    "Weekly" : "Setmanalment",
    "Settings" : "Configuració",
    "Enable RSS feed" : "Activa el canal RSS",
    "No more events to load" : "No hi ha més elements a carregar",
    "Files" : "Fitxers",
    "Error loading activities" : "Error en carregar les activitats",
    "No activities" : "Sense activitat",
    "You are receiving this email because the following things happened at %s" : "Esteu rebent aquest correu perquè han succeït les següents coses a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* i %n més ","* i %n més "]
},
"nplurals=2; plural=(n != 1);");
